<?php
/*
 * @component ZoneNationsPay
 * @copyright Copyright (C) 2023 Druskus ZoneNations https://zonenations.com
 * @license GNU/GPL v2 http://www.gnu.org/licenses/gpl-2.0.html
 */
defined('_JEXEC') or die('Restricted access');

use Joomla\CMS\MVC\View\HtmlView;
use Joomla\CMS\HTML\Helpers\Sidebar;
use Joomla\CMS\Uri\Uri;
use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Toolbar\ToolbarHelper;

class ZoneNationsPayViewpayout extends HtmlView
{
    public function display($tpl = null)
    {
        $this->sidebar = Sidebar::render();

        $this->assetpath = Uri::base(true)."/components/com_zonenationspay/assets/";
        $wa = $this->document->getWebAssetManager();
        $wa->registerAndUseStyle('zonenationspay', $this->assetpath . 'zonenationspay.css');

        $model = $this->getModel('payout');

        // Get data from the model
        $items = $this->get('Items');
        $items = $model->addTransactions($items);
        $items = $model->payoutSums($items);
        $items = $model->getOpenSimNames($items);

        $this->state = $this->get('State');

        $task = Factory::getApplication()->input->get('task');

        switch($task) {
            case "changestatus":
                $payoutid = Factory::getApplication()->input->get('payoutID');
                $this->item = $model->getItemFromID($items, $payoutid);
                $tpl = "changestatus";
                break;
            default:
                $pagination = $this->get('Pagination');
        
                // Check for errors.
                if ($errors = $this->get('Errors')) {
                    throw new Exception(implode("\n", $errors), 500);
                }
                // Assign data to the view
                $this->items = $items;
                $this->pagination = $pagination;
                $this->searchterms = $this->state->get('filter.search');

                $this->setToolbar($tpl);
                break;
        }

        parent::display($tpl);
    }

    public function setToolbar($tpl)
    {
        switch($tpl) {
            case "editcss":
                ToolbarHelper::apply('applycss');
                ToolbarHelper::save('savecss');
                ToolbarHelper::cancel();
                break;
            case "csserror":
                ToolbarHelper::cancel();
                break;
            default:
                ToolbarHelper::title(Text::_('COM_ZONENATIONSPAY_CONTROL_PANEL'), 'zonenationspay');
                if (Factory::getUser()->authorise('core.admin', 'com_zonenationspay')) {
                    ToolbarHelper::preferences('com_zonenationspay', '700', '950', Text::_('COM_ZONENATIONSPAY_OPTIONS'));
                    // ToolbarHelper::custom('editcss', 'css.png', 'css_f2.png', 'ZONENATIONS_EDITCSS', false);
                }
                ToolbarHelper::help("", false, Text::_('ZONENATIONS_HELP'));
                break;
        }
    }
}