<?php
/*
 * @component ZoneNationsPay
 * @copyright Copyright (C) 2023 Druskus ZoneNations https://zonenations.com
 * @license GNU/GPL v2 http://www.gnu.org/licenses/gpl-2.0.html
 */
defined('_JEXEC') or die('Restricted access');

use Joomla\CMS\MVC\View\HtmlView;
use Joomla\CMS\HTML\Helpers\Sidebar;
use Joomla\CMS\Factory;
use Joomla\CMS\Uri\Uri;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Toolbar\ToolbarHelper;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Installer\Installer;
use Joomla\CMS\Filesystem\File;

class ZoneNationsPayViewZoneNationsPay extends HtmlView
{
    public function display($tpl = null)
    {
        $this->debug = null;
        HTMLHelper::_('bootstrap.modal');
        $this->sidebar = Sidebar::render();
        $wa = $this->document->getWebAssetManager();
        $this->assetpath = Uri::base(true)."/components/com_zonenationspay/assets/";
        $wa->registerAndUseStyle('zonenationspay', $this->assetpath.'zonenationspay.css');

        $assetpath = Uri::base(true)."/components/com_opensim/assets/";
        $wa->registerAndUseStyle('opensim', $assetpath.'opensim.css');
        $wa->registerAndUseStyle('quickiconstyle', $assetpath.'quickiconstyle.css', [], ['version' => '2.6.8']);

        $model = $this->getModel('zonenationspay');
        $model->checkParams();
        $this->params = $model->getParams();
        $this->user = Factory::getUser();
        $this->newtransactions = $model->newTransactions($this->user->lastvisitDate);
        $this->newpayouts = $model->newPayouts($this->user->lastvisitDate);
        $this->unsolvedpayouts = $model->unsolvedPayouts();

        $this->adminbuttons['transactions'] = $this->renderButton('index.php?option=com_zonenationspay&view=transactions','transactions.png',Text::_('COM_ZONENATIONSPAY_MENU_TRANSACTIONS'));
        $this->adminbuttons['payout'] = $this->renderButton('index.php?option=com_zonenationspay&view=payout','payout.png',Text::_('COM_ZONENATIONSPAY_MENU_PAYOUT'));

        $this->zonenationspayVersion = $this->getZoneNationsPayVersion();

        $this->setToolbar($tpl);
        parent::display($tpl);
    }

    public function renderButton($link, $image, $text)
    {
        $params = ['title' => $text, 'border' => '0'];
        $button = "<div class='icon-wrapper'>";
        $button .= "<div class='icon'>";
        $button .= sprintf("<a href='%s' class='os_mainscreen'>", $link);
        $button .= HTMLHelper::_('image', 'administrator/components/com_zonenationspay/assets/images/'.$image, $text, $params);
        $button .= sprintf("<span>%s</span></a>", $text);
        $button .= "</div></div>\n";
        return $button;
    }

    public function getZoneNationsPayVersion()
    {
        $file = JPATH_ADMINISTRATOR.'/components/com_zonenationspay/zonenationspay.xml';
        if (File::exists($file)) {
            $data = Installer::parseXMLInstallFile($file);
            if ($data && isset($data['version'])) {
                return $data['version'];
            }
        }
        return 'Version not found';
    }

    public function setToolbar($tpl)
    {
        ToolbarHelper::title(Text::_('COM_ZONENATIONSPAY_CONTROL_PANEL'), 'zonenationspay');
        if (Factory::getUser()->authorise('core.admin', 'com_zonenationspay')) {
            ToolbarHelper::preferences('com_zonenationspay', '700', '950', Text::_('COM_ZONENATIONSPAY_OPTIONS'));
        }
        ToolbarHelper::help("", false, Text::_('ZONENATIONS_HELP'));
    }
}