<?php
defined('_JEXEC') or die;

use Joomla\CMS\MVC\Controller\BaseController;
use Joomla\CMS\Factory;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Language\Text;

class ZonenationspayControllerBtcpay extends BaseController
{
    public function display($cachable = false, $urlparams = [])
    {
        $view = $this->getView('btcpay', 'html');
        $model = $this->getModel('btcpay');
        $view->setModel($model, true);

        $view->display();
    }

    public function process()
    {
        $app = Factory::getApplication();
        $input = $app->input;
        $amount = $input->get('amount', 0, 'float');
        $aviKey = $input->get('aviKey', '', 'string');
        $model = $this->getModel('btcpay');

        if ($model->hasPendingInvoice($aviKey)) {
            $app->enqueueMessage(Text::_('COM_ZONENATIONSPAY_BTCPAY_PENDING_INVOICE'), 'warning');
            $this->setRedirect(Route::_('index.php?option=com_zonenationspay&view=btcpay', false));
            return;
        }

        $result = $model->requestInvoice($aviKey, $amount);
        if (isset($result['checkoutLink'])) {
            $app->redirect($result['checkoutLink']);
        } else {
            $app->enqueueMessage(Text::_('COM_ZONENATIONSPAY_BTCPAY_INVOICE_REQUEST_FAILED'), 'error');
            $this->setRedirect(Route::_('index.php?option=com_zonenationspay&view=btcpay', false));
        }
    }

    public function requestWithdrawal()
    {
        $this->checkToken();

        $app = Factory::getApplication();
        $model = $this->getModel('btcpay');
        $input = $app->input;

        $account = $input->getString('account');
        $securityHash = $input->getString('securityHash');
        $avatarSecureId = $input->getString('avatarSecureId');
        $amount = $input->getFloat('amount');
        $address = $input->getString('address');

        $result = $model->requestWithdrawal($account, $avatarSecureId, $amount, $address);

        if ($result['success']) {
            $app->redirect($result['link']);
        } else {
            $app->enqueueMessage(Text::_('COM_ZONENATIONSPAY_WITHDRAWAL_REQUEST_FAILED'), 'error');
            $this->setRedirect(Route::_('index.php?option=com_zonenationspay&view=btcpay', false));
        }
    }

    public function sendWithdrawalLink()
    {
        $this->checkToken();

        $app = Factory::getApplication();
        $model = $this->getModel('btcpay');
        $input = $app->input;

        $aviKey = $input->getString('aviKey');

        if (!$model->isUUID($aviKey)) {
            $app->enqueueMessage(Text::_('COM_ZONENATIONSPAY_INVALID_AVATAR_UUID'), 'error');
            $this->setRedirect(Route::_('index.php?option=com_zonenationspay&view=btcpay', false));
            return;
        }

        $hash = $model->getLinkHash($aviKey, $_SERVER['REMOTE_ADDR']);
        $result = $model->sendWithdrawalLinkRequest($aviKey, $hash);

        if ($result) {
            $app->enqueueMessage(Text::_('COM_ZONENATIONSPAY_WITHDRAWAL_LINK_SENT'), 'message');
        } else {
            $app->enqueueMessage(Text::_('COM_ZONENATIONSPAY_WITHDRAWAL_LINK_SEND_FAILED'), 'error');
        }

        $this->setRedirect(Route::_('index.php?option=com_zonenationspay&view=btcpay', false));
    }
}

