<?php
/**
 * @component ZoneNationsPay
 * @copyright Copyright (C) 2023 Druskus ZoneNations https://www.zonenations.com
 * @license GNU/GPL v2 http://www.gnu.org/licenses/gpl-2.0.html
 */

defined('_JEXEC') or die('Restricted access');

use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;
use Joomla\CMS\MVC\Controller\BaseController;

class ZonenationspayControllerPayout extends BaseController
{
    public function payout()
    {
        // Check for request forgeries
        $this->checkToken();

        $model = $this->getModel('payout');
        $retval = $model->savePayoutRequest();

        if ($retval === true) {
            $type = "message";
            $message = Text::_('COM_ZONENATIONSPAY_PAYOUTOK');
        } else {
            $type = "error";
            $message = Text::_('COM_ZONENATIONSPAY_PAYOUTERROR') . ($this->app->isClient('administrator') ? var_export($retval, true) : '');
        }

        $app = Factory::getApplication();
        $itemid = $app->input->getInt('Itemid');
        $return = $app->input->getCmd('returnto', '');

        switch ($return) {
            case "zonenations":
                $redirect = "index.php?option=com_opensim&view=inworld&task=money&Itemid=" . $itemid;
                break;
            default:
                $redirect = "index.php?option=com_zonenationspay&view=transactionlist&noadd=1&Itemid=" . $itemid;
                break;
        }

        // Check if this payout affects any region rent
        if ($retval === true) {
            $this->handleRegionRentPayout($model);
        }

        $this->setRedirect($redirect, $message, $type);
    }

    protected function handleRegionRentPayout($model)
    {
        $user = Factory::getUser();
        $regionRents = $model->getRegionRentsDue($user->id);

        foreach ($regionRents as $rent) {
            $payoutAmount = $model->getLastPayoutAmount($user->id);
            if ($payoutAmount >= $rent->amount) {
                $model->payRegionRent($rent->id, $payoutAmount);
                $payoutAmount -= $rent->amount;

                $message = Text::sprintf('COM_ZONENATIONSPAY_REGIONRENT_PAID', $rent->region_name, $rent->amount);
                $this->app->enqueueMessage($message, 'success');
            }
        }
    }
}
