<?php
defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;
use Joomla\CMS\MVC\Model\BaseDatabaseModel;
use Joomla\CMS\Component\ComponentHelper;
use Joomla\CMS\Date\Date;
use Joomla\CMS\Router\Route;

class ZonenationspayModelBtcpay extends BaseDatabaseModel
{
    protected $btcpayClient;

    public function __construct($config = array())
    {
        parent::__construct($config);
        $this->btcpayClient = $this->getBTCPayClient();
    }

    protected function getBTCPayClient()
    {
        $params = ComponentHelper::getParams('com_zonenationspay');
        $host = $params->get('btcpay_host');
        $apiKey = $params->get('btcpay_api_key');
        
        // You need to replace this with the actual BTCPay Server client initialization
        // This is just a placeholder
        return new \BTCPayServer\Client\Client($host, $apiKey);
    }

    public function getCurrencyStatus()
    {
        $params = ComponentHelper::getParams('com_zonenationspay');
        return !$params->get('btcpay_enabled', true);
    }

    public function getSupportedCrypto()
    {
        $params = ComponentHelper::getParams('com_zonenationspay');
        return $params->get('btcpay_crypto', 'BTC');
    }

    public function getSupportedFiat()
    {
        $params = ComponentHelper::getParams('com_zonenationspay');
        return $params->get('btcpay_fiat', 'USD');
    }

    public function getLocalCurrencySymbol()
    {
        $params = ComponentHelper::getParams('com_zonenationspay');
        return $params->get('local_currency_symbol', '$');
    }

    public function getMinimumAmount()
    {
        $params = ComponentHelper::getParams('com_zonenationspay');
        return $params->get('btcpay_minimum_amount', 10);
    }

    public function getBuyPrice()
    {
        try {
            $crypto = $this->getSupportedCrypto();
            $fiat = $this->getSupportedFiat();
            $rate = $this->btcpayClient->getRates($crypto, $fiat);
            return $rate;
        } catch (Exception $e) {
            Factory::getApplication()->enqueueMessage(Text::_('COM_ZONENATIONSPAY_BTCPAY_RATE_FETCH_ERROR'), 'error');
            return null;
        }
    }

    public function getPullPaymentLink()
    {
        $params = ComponentHelper::getParams('com_zonenationspay');
        return $params->get('btcpay_pull_payment_link', '');
    }

    public function hasPendingInvoice($aviKey)
    {
        $db = $this->getDbo();
        $query = $db->getQuery(true)
            ->select('COUNT(*)')
            ->from($db->quoteName('#__zonenationspay_invoices'))
            ->where($db->quoteName('avi_key') . ' = ' . $db->quote($aviKey))
            ->where($db->quoteName('status') . ' = ' . $db->quote('pending'));
        $db->setQuery($query);
        return (bool) $db->loadResult();
    }

    public function requestInvoice($aviKey, $amount)
    {
        try {
            $invoiceData = [
                'amount' => $amount,
                'currency' => $this->getSupportedFiat(),
                'orderId' => uniqid('ZNP_'),
                'notificationUrl' => Route::_('index.php?option=com_zonenationspay&task=btcpay.ipn', true, -1),
                'redirectUrl' => Route::_('index.php?option=com_zonenationspay&view=btcpay&layout=success', true, -1),
                'metadata' => [
                    'aviKey' => $aviKey,
                ],
            ];
            $invoice = $this->btcpayClient->createInvoice($invoiceData);
            $this->saveInvoice($invoice, $aviKey);
            return [
                'id' => $invoice->getId(),
                'checkoutLink' => $invoice->getCheckoutLink(),
            ];
        } catch (Exception $e) {
            Factory::getApplication()->enqueueMessage(Text::_('COM_ZONENATIONSPAY_BTCPAY_INVOICE_CREATE_ERROR'), 'error');
            return null;
        }
    }

    protected function saveInvoice($invoice, $aviKey)
    {
        $db = $this->getDbo();
        $obj = new stdClass();
        $obj->invoice_id = $invoice->getId();
        $obj->avi_key = $aviKey;
        $obj->amount = $invoice->getAmount();
        $obj->currency = $invoice->getCurrency();
        $obj->status = $invoice->getStatus();
        $obj->created_date = (new Date())->toSql();
        $db->insertObject('#__zonenationspay_invoices', $obj);
    }

    public function getWithdrawalStatus()
    {
        $params = ComponentHelper::getParams('com_zonenationspay');
        return !$params->get('btcpay_withdrawals_enabled', true);
    }

    public function getAvatarSession($account)
    {
        $db = $this->getDbo();
        $query = $db->getQuery(true)
            ->select('SessionID, SecureSessionID')
            ->from($db->quoteName('#__opensim_presence'))
            ->where($db->quoteName('UserID') . ' = ' . $db->quote($account))
            ->order($db->quoteName('Login') . ' DESC');
        $db->setQuery($query, 0, 1);
        return $db->loadAssoc();
    }

    public function getHash($account, $avatarSecureId, $avatarSession, $ipAddress)
    {
        return hash('sha256', $account . $avatarSecureId . $avatarSession . $ipAddress);
    }

    public function getAvatarName($account)
    {
        $db = $this->getDbo();
        $query = $db->getQuery(true)
            ->select('FirstName, LastName')
            ->from($db->quoteName('#__opensim_useraccounts'))
            ->where($db->quoteName('PrincipalID') . ' = ' . $db->quote($account));
        $db->setQuery($query);
        $result = $db->loadAssoc();
        return $result ? $result['FirstName'] . ' ' . $result['LastName'] : '';
    }

    public function getBalance($account, $avatarSecureId)
    {
        $db = $this->getDbo();
        $query = $db->getQuery(true)
            ->select('balance')
            ->from($db->quoteName('#__zonenationspay_accounts'))
            ->where($db->quoteName('account_id') . ' = ' . $db->quote($account));
        $db->setQuery($query);
        return (float) $db->loadResult();
    }

    public function convertToReal($amount, $isWithdrawal)
    {
        $params = ComponentHelper::getParams('com_zonenationspay');
        $rate = $isWithdrawal ? $params->get('withdrawal_rate', 1) : $params->get('deposit_rate', 1);
        $fiatAmount = $amount * $rate;
        $cryptoRate = $this->getBuyPrice();
        $cryptoAmount = $cryptoRate ? $fiatAmount / $cryptoRate : 0;

        return [
            'fiatAmount' => $fiatAmount,
            'cryptoAmount' => $cryptoAmount,
            'rate' => $cryptoRate
        ];
    }

    public function hasPendingPayout($account)
    {
        $db = $this->getDbo();
        $query = $db->getQuery(true)
            ->select('id')
            ->from($db->quoteName('#__zonenationspay_payouts'))
            ->where($db->quoteName('account_id') . ' = ' . $db->quote($account))
            ->where($db->quoteName('status') . ' IN (' . $db->quote('pending') . ',' . $db->quote('processing') . ')');
        $db->setQuery($query);
        return $db->loadResult();
    }

    public function isUUID($uuid)
    {
        return preg_match('/^[0-9A-F]{8}-[0-9A-F]{4}-4[0-9A-F]{3}-[89AB][0-9A-F]{3}-[0-9A-F]{12}$/i', $uuid);
    }

    public function getLinkHash($aviKey, $ipAddress)
    {
        return hash('sha256', $aviKey . $ipAddress . time());
    }

    public function sendWithdrawalLinkRequest($aviKey, $hash)
    {
        $avatarName = $this->getAvatarName($aviKey);
        $withdrawalLink = Route::_('index.php?option=com_zonenationspay&view=btcpay&task=withdrawal&key=' . $hash, true, -1);
        $message = Text::sprintf('COM_ZONENATIONSPAY_WITHDRAWAL_LINK_MESSAGE', $avatarName, $withdrawalLink);
        
        return $this->sendMessageToAvatar($aviKey, $message);
    }

    protected function sendMessageToAvatar($aviKey, $message)
    {
        $params = ComponentHelper::getParams('com_zonenationspay');
        $opensimUrl = $params->get('opensim_url', 'http://localhost:9000');
        $opensimPassword = $params->get('opensim_password', '');

        $url = $opensimUrl . '/admin/json2/';
        $postData = json_encode([
            'method' => 'user_alert',
            'params' => [
                'avatar_uuid' => $aviKey,
                'message' => $message
            ]
        ]);

        $ch = curl_init($url);
        curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "POST");
        curl_setopt($ch, CURLOPT_POSTFIELDS, $postData);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, [
            'Content-Type: application/json',
            'Content-Length: ' . strlen($postData),
            'Authentication: ' . $opensimPassword
        ]);

        $result = curl_exec($ch);
        $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        curl_close($ch);

        if ($httpCode === 200) {
            $response = json_decode($result, true);
            if (isset($response['success']) && $response['success'] === true) {
                return true;
            }
        }

        $this->logError('Failed to send message to avatar: ' . $aviKey . '. HTTP Code: ' . $httpCode . '. Response: ' . $result);
        return false;
    }

    public function requestWithdrawal($account, $avatarSecureId, $amount, $address)
    {
        try {
            $balance = $this->getBalance($account, $avatarSecureId);
            if ($balance < $amount) {
                throw new Exception(Text::_('COM_ZONENATIONSPAY_INSUFFICIENT_BALANCE'));
            }

            $conversion = $this->convertToReal($amount, true);
            $pullPaymentData = [
                'amount' => $conversion['fiatAmount'],
                'currency' => $this->getSupportedFiat(),
                'destination' => $address,
                'metadata' => [
                    'account' => $account,
                    'originalAmount' => $amount
                ]
            ];

            $pullPayment = $this->btcpayClient->createPullPayment($pullPaymentData);
            $this->savePullPayment($pullPayment, $account, $amount);

            return [
                'success' => true,
                'link' => $pullPayment->getViewLink()
            ];
        } catch (Exception $e) {
            Factory::getApplication()->enqueueMessage($e->getMessage(), 'error');
            return [
                'success' => false,
                'message' => $e->getMessage()
            ];
        }
    }

    protected function savePullPayment($pullPayment, $account, $amount)
    {
        $db = $this->getDbo();
        $obj = new stdClass();
        $obj->pull_payment_id = $pullPayment->getId();
        $obj->account_id = $account;
        $obj->amount = $amount;
        $obj->status = 'pending';
        $obj->created_date = (new Date())->toSql();
        $db->insertObject('#__zonenationspay_payouts', $obj);
    }

    protected function logError($message)
    {
        $logFile = JPATH_ROOT . '/logs/zonenationspay_errors.php';
        $date = new Date();
        $logMessage = $date->format('Y-m-d H:i:s') . ' - ' . $message . "\n";
        file_put_contents($logFile, $logMessage, FILE_APPEND);
    }
}


