<?php
defined('_JEXEC') or die;

use Joomla\CMS\MVC\Model\BaseDatabaseModel;
use Joomla\CMS\Factory;
use Joomla\CMS\Date\Date;

class ZonenationspayModelRegionrent extends BaseDatabaseModel
{
    public function getRegionRents($userId)
    {
        $db = $this->getDbo();
        $query = $db->getQuery(true)
            ->select('*')
            ->from($db->quoteName('#__zonenationspay_regionrents'))
            ->where($db->quoteName('user_id') . ' = ' . (int)$userId);
        
        $db->setQuery($query);
        return $db->loadObjectList();
    }

    public function getUpcomingRentPayments($userId, $daysAhead = 7)
    {
        $db = $this->getDbo();
        $now = new Date();
        $futureDate = new Date('+' . $daysAhead . ' days');
        
        $query = $db->getQuery(true)
            ->select('*')
            ->from($db->quoteName('#__zonenationspay_regionrents'))
            ->where($db->quoteName('user_id') . ' = ' . (int)$userId)
            ->where($db->quoteName('due_date') . ' BETWEEN ' . $db->quote($now->toSql()) . ' AND ' . $db->quote($futureDate->toSql()));
        
        $db->setQuery($query);
        return $db->loadObjectList();
    }

    public function getOverdueRentPayments($userId)
    {
        $db = $this->getDbo();
        $now = new Date();
        
        $query = $db->getQuery(true)
            ->select('*')
            ->from($db->quoteName('#__zonenationspay_regionrents'))
            ->where($db->quoteName('user_id') . ' = ' . (int)$userId)
            ->where($db->quoteName('due_date') . ' < ' . $db->quote($now->toSql()))
            ->where($db->quoteName('status') . ' = ' . $db->quote('unpaid'));
        
        $db->setQuery($query);
        return $db->loadObjectList();
    }

    public function processRentPayment($rentId)
    {
        $db = $this->getDbo();
        $date = Factory::getDate();
        $user = Factory::getUser();

        // Inizia una transazione
        $db->transactionStart();

        try {
            // 1. Ottieni i dettagli dell'affitto
            $query = $db->getQuery(true)
                ->select('*')
                ->from($db->quoteName('#__zonenationspay_regionrents'))
                ->where($db->quoteName('id') . ' = ' . (int)$rentId);
            $db->setQuery($query);
            $rent = $db->loadObject();

            if (!$rent) {
                throw new Exception('Rent record not found');
            }

            // 2. Verifica che l'utente abbia fondi sufficienti
            $userBalance = $this->getUserBalance($user->id);
            if ($userBalance < $rent->amount) {
                throw new Exception('Insufficient funds');
}public function processRentPayment($rentId)
{
    $db = $this->getDbo();
    $date = Factory::getDate();
    $user = Factory::getUser();

    // Inizia una transazione
    $db->transactionStart();

    try {
        // 1. Ottieni i dettagli dell'affitto
        $query = $db->getQuery(true)
            ->select('*')
            ->from($db->quoteName('#__zonenationspay_regionrents'))
            ->where($db->quoteName('id') . ' = ' . (int)$rentId);
        $db->setQuery($query);
        $rent = $db->loadObject();

        if (!$rent) {
            throw new Exception('Rent record not found');
        }

        // 2. Verifica che l'utente abbia fondi sufficienti
        $userBalance = $this->getUserBalance($user->id);
        if ($userBalance < $rent->amount) {
            throw new Exception('Insufficient funds');
        }

        // 3. Sottrai l'importo dal saldo dell'utente
        $newBalance = $userBalance - $rent->amount;
        $this->updateUserBalance($user->id, $newBalance);

        // 4. Aggiorna lo stato dell'affitto
        $query = $db->getQuery(true)
            ->update($db->quoteName('#__zonenationspay_regionrents'))
            ->set($db->quoteName('status') . ' = ' . $db->quote('paid'))
            ->set($db->quoteName('paid_date') . ' = ' . $db->quote($date->toSql()))
            ->where($db->quoteName('id') . ' = ' . (int)$rentId);
        $db->setQuery($query);
        $db->execute();

        // 5. Registra la transazione
        $this->logTransaction($user->id, $rent->amount, 'region_rent', $rentId);

        // 6. Estendi la data di scadenza dell'affitto
        $nextDueDate = new Date($rent->due_date);
        $nextDueDate->modify('+1 month'); // Assumiamo che l'affitto sia mensile
        $query = $db->getQuery(true)
            ->update($db->quoteName('#__zonenationspay_regionrents'))
            ->set($db->quoteName('due_date') . ' = ' . $db->quote($nextDueDate->toSql()))
            ->where($db->quoteName('id') . ' = ' . (int)$rentId);
        $db->setQuery($query);
        $db->execute();

        // Commit della transazione
        $db->transactionCommit();
        return true;
    } catch (Exception $e) {
        // Rollback in caso di errore
        $db->transactionRollback();
        Factory::getApplication()->enqueueMessage($e->getMessage(), 'error');
        return false;
    }
}

private function getUserBalance($userId)
{
    // Implementa la logica per ottenere il saldo dell'utente
    $db = $this->getDbo();
    $query = $db->getQuery(true)
        ->select('balance')
        ->from($db->quoteName('#__zonenationspay_user_balances'))
        ->where($db->quoteName('user_id') . ' = ' . (int)$userId);
    $db->setQuery($query);
    return (float) $db->loadResult();
}

private function updateUserBalance($userId, $newBalance)
{
    // Implementa la logica per aggiornare il saldo dell'utente
    $db = $this->getDbo();
    $query = $db->getQuery(true)
        ->update($db->quoteName('#__zonenationspay_user_balances'))
        ->set($db->quoteName('balance') . ' = ' . (float)$newBalance)
        ->where($db->quoteName('user_id') . ' = ' . (int)$userId);
    $db->setQuery($query);
    $db->execute();
}

private function logTransaction($userId, $amount, $type, $relatedId)
{
    // Implementa la logica per registrare la transazione
    $db = $this->getDbo();
    $date = Factory::getDate();
    $columns = array('user_id', 'amount', 'type', 'related_id', 'transaction_date');
    $values = array(
        (int)$userId,
        (float)$amount,
        $db->quote($type),
        (int)$relatedId,
        $db->quote($date->toSql())
    );
    $query = $db->getQuery(true)
        ->insert($db->quoteName('#__zonenationspay_transactions'))
        ->columns($db->quoteName($columns))
        ->values(implode(',', $values));
    $db->setQuery($query);
    $db->execute();
}


            // 3. Sottrai l'importo dal saldo dell'utente
            $newBalance = $userBalance - $rent->amount;
            $this->updateUserBalance($user->id, $newBalance);

            // 4. Aggiorna lo stato dell'affitto
            $query = $db->getQuery(true)
                ->update($db->quoteName('#__zonenationspay_regionrents'))
                ->set($db->quoteName('status') . ' = ' . $db->quote('paid'))
                ->set($db->quoteName('paid_date') . ' = ' . $db->quote($date->toSql()))
                ->where($db->quoteName('id') . ' = ' . (int)$rentId);
            $db->setQuery($query);
            $db->execute();

            // 5. Registra la transazione
            $this->logTransaction($user->id, $rent->amount, 'region_rent', $rentId);

            // 6. Estendi la data di scadenza dell'affitto
            $nextDueDate = new Date($rent->due_date);
            $nextDueDate->modify('+1 month'); // Assumiamo che l'affitto sia mensile
            $query = $db->getQuery(true)
                ->update($db->quoteName('#__zonenationspay_regionrents'))
                ->set($db->quoteName('due_date') . ' = ' . $db->quote($nextDueDate->toSql()))
                ->where($db->quoteName('id') . ' = ' . (int)$rentId);
            $db->setQuery($query);
            $db->execute();

            // Commit della transazione
            $db->transactionCommit();
            return true;
        } catch (Exception $e) {
            // Rollback in caso di errore
            $db->transactionRollback();
            Factory::getApplication()->enqueueMessage($e->getMessage(), 'error');
            return false;
        }
    }

    private function getUserBalance($userId)
    {
        // Implementa la logica per ottenere il saldo dell'utente
        $db = $this->getDbo();
        $query = $db->getQuery(true)
            ->select('balance')
            ->from($db->quoteName('#__zonenationspay_user_balances'))
            ->where($db->quoteName('user_id') . ' = ' . (int)$userId);
        $db->setQuery($query);
        return (float) $db->loadResult();
    }

    private function updateUserBalance($userId, $newBalance)
    {
        // Implementa la logica per aggiornare il saldo dell'utente
        $db = $this->getDbo();
        $query = $db->getQuery(true)
            ->update($db->quoteName('#__zonenationspay_user_balances'))
            ->set($db->quoteName('balance') . ' = ' . (float)$newBalance)
            ->where($db->quoteName('user_id') . ' = ' . (int)$userId);
        $db->setQuery($query);
        $db->execute();
    }

    private function logTransaction($userId, $amount, $type, $relatedId)
    {
        // Implementa la logica per registrare la transazione
        $db = $this->getDbo();
        $date = Factory::getDate();
        $columns = array('user_id', 'amount', 'type', 'related_id', 'transaction_date');
        $values = array(
            (int)$userId,
            (float)$amount,
            $db->quote($type),
            (int)$relatedId,
            $db->quote($date->toSql())
        );
        $query = $db->getQuery(true)
            ->insert($db->quoteName('#__zonenationspay_transactions'))
            ->columns($db->quoteName($columns))
            ->values(implode(',', $values));
        $db->setQuery($query);
        $db->execute();
    }
}
