<?php
/**
 * @component ZoneNationsPay
 * @copyright Copyright (C) 2023 Druskus ZoneNations https://www.zonenations.com
 * @license GNU/GPL v2 http://www.gnu.org/licenses/gpl-2.0.html
 */

defined('_JEXEC') or die();

use Joomla\CMS\MVC\Model\BaseDatabaseModel;
use Joomla\CMS\Component\ComponentHelper;
use Joomla\CMS\Factory;
use Joomla\CMS\Date\Date;
use Joomla\CMS\Log\Log;

class ZonenationspayModelZoneNationsPay extends BaseDatabaseModel
{
    protected $moneySettingsData;
    protected $params = [];
    public $filename = "zonenationspay.php";
    public $view = "zonenationspay";
    public $paypalHost;

    public function __construct($config = array())
    {
        parent::__construct($config);
        $this->getMoneySettings();
        $this->getParams();
    }

    public function getParams()
    {
        $params = ComponentHelper::getParams('com_zonenationspay');

        // PayPal params
        $this->params['sandboxMode'] = $params->get('sandboxmode', 0);
        if ($this->params['sandboxMode']) {
            $this->params['paypal_account'] = $params->get('paypal_sandbox');
            $this->params['paypal_action'] = "https://www.sandbox.paypal.com/cgi-bin/webscr";
            $this->paypalHost = "www.sandbox.paypal.com";
            $this->paypalMode = "sandbox";
        } else {
            $this->params['paypal_account'] = $params->get('paypal_account');
            $this->params['paypal_action'] = "https://www.paypal.com/cgi-bin/webscr";
            $this->paypalHost = "www.paypal.com";
            $this->paypalMode = "production";
        }
        $this->params['paypal_nossl'] = $params->get('paypal_nossl', 0);

        // Currency params
        $this->params['currency'] = $params->get('currency', 'USD');
        $this->params['currencyRateBuy'] = $params->get('currencyratebuy', 1);
        $this->params['currencyRateSell'] = $params->get('currencyratesell', 1);
        $this->params['transactionFee'] = $params->get('transactionfee', 0);
        $this->params['hasFee'] = (bool)$this->params['transactionFee'];
        $this->params['transactionFeeType'] = $params->get('transactionfeetype', 'fixed');
        $this->params['minBuy'] = $params->get('minbuy', 0);
        $this->params['maxBuy'] = $params->get('maxbuy', 0);
        $this->params['minSell'] = $params->get('minsell', 0);
        $this->params['maxSell'] = $params->get('maxsell', 0);
        $this->params['transactionText'] = $params->get('transactiontext', 'ZoneNationsPay Transaction');

        // Text params
        $this->params['preMessage'] = $params->get('pre_message');
        $this->params['postMessage'] = $params->get('post_message');
        $this->params['successMessage'] = $params->get('success_message');
        $this->params['cancelMessage'] = $params->get('cancel_message');
        $this->params['sellPreMessage'] = $params->get('sell_pre_message');
        $this->params['sellPostMessage'] = $params->get('sell_post_message');

        // User limit params
        $this->params['userLimitDay'] = $params->get('userlimit_day', 0);
        $this->params['userLimitWeek'] = $params->get('userlimit_week', 0);
        $this->params['userLimitMonth'] = $params->get('userlimit_month', 0);

        // Notify params
        $this->params['notifyTransaction'] = $params->get('notifytransaction', 0);
        $this->params['notifyError'] = $params->get('notifyerror', 0);
        $this->params['notifyWarning'] = $params->get('notifywarning', 0);
        $this->params['notifyPayout'] = $params->get('notifypayout', 0);
        $this->params['notifyEmail'] = $params->get('notifyemail');
        $this->params['log2file'] = $params->get('log2file', 0);
        $this->params['logPath'] = $params->get('logpath', JPATH_ROOT . '/logs');

        // Region Rent params
        $this->params['enableRegionRent'] = $params->get('enable_region_rent', 0);
        $this->params['regionRentNotifyDays'] = $params->get('region_rent_notify_days', 7);
    }

    public function getParam($paramName)
    {
        return $paramName === "all" ? $this->params : ($this->params[$paramName] ?? null);
    }

    public function getMoneySettings()
    {
        if (empty($this->moneySettingsData)) {
            $params = ComponentHelper::getParams('com_opensim');
            $this->moneySettingsData = [
                'name' => $params->get('jopensimmoney_currencyname', 'IWC'),
                'bankerUID' => $params->get('jopensimmoneybanker'),
                'groupCharge' => $params->get('jopensimmoney_groupcreation', 0),
                'uploadCharge' => $params->get('jopensimmoney_upload', 0),
                'groupMinDividend' => $params->get('jopensimmoney_groupdividend', 0),
                'startBalance' => $params->get('jopensimmoney_startbalance', 0),
                'currencyDebug' => $params->get('jopensim_debug_currency', 0)
            ];

            if (!defined("_JOPENSIMMONEYDEBUG")) {
                define("_JOPENSIMMONEYDEBUG", (bool)$this->moneySettingsData['currencyDebug']);
            }
        }
        return $this->moneySettingsData;
    }

    public function getMoneySetting($name)
    {
        $this->getMoneySettings();
        return $this->moneySettingsData[$name] ?? null;
    }

    public function getUUID($userId)
    {
        $db = $this->getDbo();
        $query = $db->getQuery(true)
            ->select($db->quoteName('opensimID'))
            ->from($db->quoteName('#__opensim_userrelation'))
            ->where($db->quoteName('joomlaID') . ' = ' . (int)$userId);
        return $db->setQuery($query)->loadResult();
    }

    public function getBalance($uuid)
    {
        $db = $this->getDbo();
        $query = $db->getQuery(true)
            ->select($db->quoteName('balance'))
            ->from($db->quoteName('#__opensim_moneybalances'))
            ->where($db->quoteName('user') . ' = ' . $db->quote($uuid));
        return $db->setQuery($query)->loadResult();
    }

    public function checkVar($var, $type)
    {
        switch ($type) {
            case "email":
                return filter_var($var, FILTER_VALIDATE_EMAIL) !== false;
            case "number":
                return is_numeric($var);
            default:
                return false;
        }
    }

    public function sendNotify($type, $handler, $msg)
    {
        $notifyEmail = $this->getParam("notifyemail");
        $logToFile = $this->getParam("log2file");

        $mailer = Factory::getMailer();
        $config = Factory::getApplication()->getConfig();
        $sender = [$config->get('mailfrom'), $config->get('fromname')];

        $mailer->setSender($sender)
               ->addRecipient($notifyEmail)
               ->setSubject($this->getNotifySubject($type))
               ->setBody($this->getNotifyBody($handler, $msg));

        try {
            $mailer->send();
        } catch (\Exception $e) {
            if ($logToFile & 1) {
                Log::add('Error sending email: ' . $e->getMessage(), Log::ERROR, 'zonenationspay');
            }
        }
    }

    protected function getNotifySubject($type)
    {
        $subjects = [
            1 => 'ZoneNationsPay Error Notification',
            2 => 'ZoneNationsPay Warning Notification',
            3 => 'ZoneNationsPay Transaction Notification',
            4 => 'ZoneNationsPay Payout Request Notification'
        ];
        return $subjects[$type] ?? 'ZoneNationsPay Notification';
    }

    protected function getNotifyBody($handler, $msg)
    {
        $bodies = [
            1 => "This is a notification about a successful transaction:\n\n",
            2 => "This is a notification about a transaction with warnings:\n\n",
            3 => "This is a notification about an error during a transaction:\n\n",
            4 => "This is a notification about a payout request:\n\n"
        ];
        return ($bodies[$handler] ?? "Unknown message handler: $handler\n\n") . $msg;
    }

    public function logMessage($message, $type = Log::INFO)
    {
        Log::add($message, $type, 'zonenationspay');
        
        if ($this->params['log2file']) {
            $logFile = $this->getLogFile();
            $logMessage = date("Y-m-d H:i:s") . "\t" . $message . "\n";
            file_put_contents($logFile, $logMessage, FILE_APPEND);
        }
    }

    protected function getLogFile()
    {
        $logPath = rtrim($this->params['logPath'], '/\\') . DIRECTORY_SEPARATOR;
        return $logPath . 'zonenationspay.log';
    }

    public function getRegionRentInfo($userId)
    {
        if (!$this->params['enableRegionRent']) {
            return [];
        }

        $db = $this->getDbo();
        $query = $db->getQuery(true)
            ->select('*')
            ->from($db->quoteName('#__zonenationspay_regionrents'))
            ->where($db->quoteName('user_id') . ' = ' . (int)$userId)
            ->order($db->quoteName('due_date') . ' ASC');

        return $db->setQuery($query)->loadObjectList();
    }

    public function checkUpcomingRentPayments()
    {
        if (!$this->params['enableRegionRent']) {
            return;
        }

        $db = $this->getDbo();
        $now = new Date();
        $notifyDate = (new Date())->modify('+' . $this->params['regionRentNotifyDays'] . ' days');

        $query = $db->getQuery(true)
            ->select('r.*, u.email')
            ->from($db->quoteName('#__zonenationspay_regionrents', 'r'))
            ->join('LEFT', $db->quoteName('#__users', 'u') . ' ON u.id = r.user_id')
            ->where($db->quoteName('r.due_date') . ' BETWEEN ' . $db->quote($now->toSql()) . ' AND ' . $db->quote($notifyDate->toSql()))
            ->where($db->quoteName('r.status') . ' = ' . $db->quote('unpaid'));

        $upcomingRents = $db->setQuery($query)->loadObjectList();

        foreach ($upcomingRents as $rent) {
            $this->sendRentNotification($rent);
        }
    }

    protected function sendRentNotification($rent)
    {
        $mailer = Factory::getMailer();
        $config = Factory::getApplication()->getConfig();
        
        $mailer->setSender([$config->get('mailfrom'), $config->get('fromname')])
               ->addRecipient($rent->email)
               ->setSubject('Region Rent Payment Due')
               ->setBody(
                   "Dear User,\n\nYour region rent payment for {$rent->region_name} is due on {$rent->due_date}. " .
                   "Please ensure you have sufficient funds in your account.\n\nAmount due: {$rent->amount} " . 
                   $this->params['currency'] . "\n\nThank you,\nZoneNationsPay Team"
               );

        try {
            $mailer->send();
        } catch (\Exception $e) {
            $this->logMessage('Error sending rent notification: ' . $e->getMessage(), Log::ERROR);
        }
    }
}
