<?php
defined('_JEXEC') or die;

use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Factory;

HTMLHelper::_('jquery.framework');
HTMLHelper::_('bootstrap.tooltip');
HTMLHelper::_('behavior.formvalidator');
HTMLHelper::_('behavior.keepalive');
HTMLHelper::_('formbehavior.chosen', 'select');

$app = Factory::getApplication();
$input = $app->input;
$account = $input->get('account', '', 'string');
$amount = $input->get('amount', $this->localCurrencyMinimum, 'float');
?>

<div id="zonenationspay-btcpay" class="zonenationspay">
    <h1><?php echo Text::_('COM_ZONENATIONSPAY_BTCPAY_TITLE'); ?></h1>
    <h2><?php echo Text::sprintf('COM_ZONENATIONSPAY_BTCPAY_BUY_TITLE', $this->localCurrencySymbol, $this->cryptoSymbol); ?></h2>
    
    <?php if ($this->isDisabled): ?>
        <div class="alert alert-warning">
            <span class="icon-warning"></span>
            <?php echo Text::sprintf('COM_ZONENATIONSPAY_BTCPAY_DISABLED', $this->cryptoSymbol); ?>
        </div>
    <?php else: ?>
        <div class="btcpay-info alert alert-info">
            <h3><?php echo Text::_('COM_ZONENATIONSPAY_BTCPAY_INFO_TITLE'); ?></h3>
            <p><?php echo Text::sprintf('COM_ZONENATIONSPAY_BTCPAY_INFO_DESC', $this->cryptoSymbol, $this->localCurrencySymbol); ?></p>
            <ul>
                <li><?php echo Text::sprintf('COM_ZONENATIONSPAY_BTCPAY_MIN_AMOUNT', $this->localCurrencyMinimum, $this->localCurrencySymbol); ?></li>
                <li><?php echo Text::sprintf('COM_ZONENATIONSPAY_BTCPAY_EXCHANGE_RATE', $this->localCurrencySymbol, $this->cryptoSymbol, $this->localCurrencyBuyPrice); ?></li>
            </ul>
        </div>

        <form action="<?php echo Route::_('index.php?option=com_zonenationspay&view=btcpay'); ?>" method="post" id="btcpayForm" class="form-validate form-horizontal">
            <div class="control-group">
                <div class="control-label">
                    <?php echo Text::sprintf('COM_ZONENATIONSPAY_BTCPAY_AMOUNT_LABEL', $this->localCurrencySymbol); ?>
                </div>
                <div class="controls">
                    <input type="number" name="amount" id="amount" value="<?php echo $amount; ?>" min="<?php echo $this->localCurrencyMinimum; ?>" required class="required" />
                </div>
            </div>
            
            <div class="control-group">
                <div class="control-label">
                    <?php echo Text::_('COM_ZONENATIONSPAY_BTCPAY_AVATAR_KEY_LABEL'); ?>
                </div>
                <div class="controls">
                    <input type="text" name="aviKey" id="aviKey" value="<?php echo $account; ?>" required class="required" />
                </div>
            </div>
            
            <div class="control-group">
                <div class="controls">
                    <button type="submit" class="btn btn-primary validate">
                        <?php echo Text::_('COM_ZONENATIONSPAY_BTCPAY_BUY_NOW'); ?>
                    </button>
                </div>
            </div>
            
            <?php echo HTMLHelper::_('form.token'); ?>
        </form>

        <div class="btcpay-faq">
            <h3><?php echo Text::_('COM_ZONENATIONSPAY_BTCPAY_FAQ_TITLE'); ?></h3>
            <dl>
                <dt><?php echo Text::_('COM_ZONENATIONSPAY_BTCPAY_FAQ_Q1'); ?></dt>
                <dd><?php echo Text::sprintf('COM_ZONENATIONSPAY_BTCPAY_FAQ_A1', $this->cryptoSymbol); ?></dd>
                
                <dt><?php echo Text::_('COM_ZONENATIONSPAY_BTCPAY_FAQ_Q2'); ?></dt>
                <dd><?php echo Text::_('COM_ZONENATIONSPAY_BTCPAY_FAQ_A2'); ?></dd>
                
                <dt><?php echo Text::_('COM_ZONENATIONSPAY_BTCPAY_FAQ_Q3'); ?></dt>
                <dd><?php echo Text::sprintf('COM_ZONENATIONSPAY_BTCPAY_FAQ_A3', $this->localCurrencySymbol); ?></dd>
            </dl>
        </div>

        <div class="btcpay-support">
            <h3><?php echo Text::_('COM_ZONENATIONSPAY_BTCPAY_SUPPORT_TITLE'); ?></h3>
            <p><?php echo Text::_('COM_ZONENATIONSPAY_BTCPAY_SUPPORT_DESC'); ?></p>
            <a href="<?php echo Route::_('index.php?option=com_contact&view=contact&id=1'); ?>" class="btn btn-info">
                <?php echo Text::_('COM_ZONENATIONSPAY_BTCPAY_CONTACT_SUPPORT'); ?>
            </a>
        </div>
    <?php endif; ?>
</div>

<script type="text/javascript">
jQuery(document).ready(function($) {
    $('#amount').on('change', function() {
        var amount = $(this).val();
        var exchangeRate = <?php echo $this->localCurrencyBuyPrice; ?>;
        var estimatedCrypto = (amount / exchangeRate).toFixed(8);
        $('#estimated-crypto').text(estimatedCrypto);
    });
});
</script>
