<?php
defined('_JEXEC') or die;

use Joomla\CMS\MVC\View\HtmlView;
use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;

class ZonenationspayViewBtcpay extends HtmlView
{
    protected $state;
    protected $params;
    protected $model;
    protected $btcpayModel;
    protected $isDisabled;
    protected $cryptoSymbol;
    protected $fiatSymbol;
    protected $localCurrencySymbol;
    protected $localCurrencyMinimum;
    protected $localCurrencyWithdrawalPrice;
    protected $localCurrencyBuyPrice;
    protected $pullPaymentLink;
    protected $aviName;
    protected $balance;
    protected $price;
    protected $account;
    protected $securityHash;
    protected $avatarSecureId;
    protected $avatarSession;
    protected $message;
    protected $defaultData;
    protected $withdrawalData;

    public function display($tpl = null)
    {
        $this->state = $this->get('State');
        $this->params = Factory::getApplication()->getParams('com_zonenationspay');
        $this->model = $this->getModel();
        $this->btcpayModel = $this->getModel('btcpay');

        $this->isDisabled = $this->getWithdrawalStatus();
        $this->cryptoSymbol = $this->getSupportedCrypto();
        $this->fiatSymbol = $this->getSupportedFiat();
        $this->localCurrencySymbol = $this->getLocalCurrencySymbol();
        $this->localCurrencyMinimum = $this->getMinimumAmount();
        $this->localCurrencyWithdrawalPrice = $this->params->get('local_currency_withdrawal_price', 1);
        $this->localCurrencyBuyPrice = $this->getBuyPrice();
        $this->pullPaymentLink = $this->getPullPaymentLink();

        // Check for errors.
        if (count($errors = $this->get('Errors'))) {
            throw new Exception(implode("\n", $errors), 500);
        }

        $input = Factory::getApplication()->input;
        $account = $input->getString('a', '');
        $securityHash = $input->getString('sh', '');
        $task = $input->getCmd('task', '');

        if ($account && $securityHash) {
            $this->handleWithdrawalRequest($account, $securityHash);
        } else {
            switch ($task) {
                case 'withdrawal':
                    $this->displayWithdrawal();
                    break;
                default:
                    $this->displayDefault();
                    break;
            }
        }

        parent::display($tpl);
    }

    protected function handleWithdrawalRequest($account, $securityHash)
    {
        $session = $this->btcpayModel->getAvatarSession($account);
        $avatarSecureId = $session['secureID'];
        $avatarSession = $session['sessionID'];
        $tempHash = $this->btcpayModel->getHash($account, $avatarSecureId, $avatarSession, $_SERVER['REMOTE_ADDR']);

        if (!hash_equals($securityHash, $tempHash)) {
            $this->setLayout('warning');
            $this->message = Text::_('COM_ZONENATIONSPAY_SECURITY_VERIFICATION_FAILED');
            return;
        }

        $this->aviName = $this->btcpayModel->getAvatarName($account);
        $this->balance = $this->btcpayModel->getBalance($account, $avatarSecureId);
        $this->price = $this->btcpayModel->convertToReal($this->balance, true);

        if ($this->price === null) {
            $this->setLayout('warning');
            $this->message = Text::_('COM_ZONENATIONSPAY_BTCPAY_SERVER_UNAVAILABLE');
            return;
        }

        $pendingPayout = $this->btcpayModel->hasPendingPayout($account);
        if ($pendingPayout !== null) {
            $this->setLayout('warning');
            $this->message = Text::sprintf('COM_ZONENATIONSPAY_PENDING_WITHDRAWAL_REQUEST', $this->pullPaymentLink . $pendingPayout);
            return;
        }

        $this->account = $account;
        $this->securityHash = $securityHash;
        $this->avatarSecureId = $avatarSecureId;
        $this->avatarSession = $avatarSession;
        $this->setLayout('form');
    }

    protected function displayDefault()
    {
        // Logic for displaying the default BTCPay view
        $this->setLayout('default');
        
        // Add any additional data needed for the default view
        $this->defaultData = $this->btcpayModel->getDefaultData();
        
        // Additional logic for default view
        $this->latestTransactions = $this->btcpayModel->getLatestTransactions();
        $this->exchangeRates = $this->btcpayModel->getExchangeRates();
        $this->userStats = $this->btcpayModel->getUserStats();
    }

    protected function displayWithdrawal()
    {
        // Logic for displaying the withdrawal form
        $this->setLayout('withdrawal');
        
        // Add any additional data needed for the withdrawal form
        $this->withdrawalData = $this->btcpayModel->getWithdrawalData();
        
        // Additional logic for withdrawal form
        $this->withdrawalFees = $this->btcpayModel->getWithdrawalFees();
        $this->withdrawalLimits = $this->btcpayModel->getWithdrawalLimits();
        $this->userWithdrawalHistory = $this->btcpayModel->getUserWithdrawalHistory();
    }

    // Helper methods from the second version
    protected function getWithdrawalStatus()
    {
        return $this->btcpayModel->getWithdrawalStatus();
    }

    protected function getSupportedCrypto()
    {
        return $this->btcpayModel->getSupportedCrypto();
    }

    protected function getSupportedFiat()
    {
        return $this->btcpayModel->getSupportedFiat();
    }

    protected function getLocalCurrencySymbol()
    {
        return $this->btcpayModel->getLocalCurrencySymbol();
    }

    protected function getMinimumAmount()
    {
        return $this->btcpayModel->getMinimumAmount();
    }

    protected function getBuyPrice()
    {
        return $this->btcpayModel->getBuyPrice();
    }

    protected function getPullPaymentLink()
    {
        return $this->btcpayModel->getPullPaymentLink();
    }
}

