<?php
<?php
/**
 * @component ZoneNationsPay
 * @copyright Copyright (C) 2023 Druskus ZoneNations https://www.zonenations.com
 * @license GNU/GPL v2 http://www.gnu.org/licenses/gpl-2.0.html
 */

// No direct access
defined('_JEXEC') or die('Restricted access');

use Joomla\CMS\MVC\View\HtmlView;
use Joomla\CMS\Factory;
use Joomla\CMS\MVC\Model\BaseDatabaseModel;

class ZonenationspayViewNotify extends HtmlView
{
    public function display($tpl = null)
    {
        $model = $this->getModel('notify');
        $cparams = $model->getParam("all");

        // Notification settings
        $notifyTransaction = $model->getParam('notifytransaction');
        $notifyError = $model->getParam('notifyerror');
        $notifyWarning = $model->getParam('notifywarning');
        $notifyEmail = $model->getParam('notifyemail');

        // Logging settings
        $logSetting = $model->getParam('log2file');
        $log2file = ($logSetting & 2) == 2;
        $failure2file = ($logSetting & 1) == 1;

        // PayPal settings
        $paypalType = $model->getParam('sandboxmode');
        $paypalAccount = $model->getParam('paypal_account');
        $sslVerify = $model->getParam('paypal_nossl');

        // Get ZoneNations interface model
        BaseDatabaseModel::addIncludePath(JPATH_SITE . '/components/com_zonenations/models', '');
        $imodel = BaseDatabaseModel::getInstance('Interface', 'ZonenationsModel', array());
        $imodel->setPayPalCall();
        $model->setMoneyModel($imodel);

        $logpath = $model->getParam('logpath');
        $paypallogfile = "zonenationspay.log";

        $app = Factory::getApplication();
        $input = $app->input;
        $this->test = $input->getString('test', null);
        $getvals = $input->get->getArray();

        if ($this->test) {
            $this->testMode($model, $notifyEmail, $paypalAccount, $logpath, $paypallogfile, $getvals);
            return;
        }

        $this->input = file_get_contents("php://input");
        if ($log2file) {
            $model->simpledebugzeile($this->input);
            $model->debugzeile($_REQUEST, "\$_REQUEST");
            $model->debugzeile($_SERVER, "\$_SERVER");
        }

        // Validate PayPal response
        $res = $model->validate();
        if ($log2file) {
            $model->debugzeile($res, "\$res");
        }

        if (strcmp($res, "VERIFIED") == 0) {
            $model->handleResponse($res);
            $this->checkRegionRentExpiration($model);
        } elseif (strcmp($res, "INVALID") == 0) {
            $this->handleInvalidResponse($model, $failure2file, $notifyError);
        } else {
            $this->handleUnknownResponse($model, $failure2file, $notifyError);
        }

        parent::display($tpl);
    }

    private function testMode($model, $notifyEmail, $paypalAccount, $logpath, $paypallogfile, $getvals)
    {
        echo "This is only a test!<br />";
        echo "notifyemail: " . $notifyEmail . "<br />\n";
        echo "paypalaccount: " . $paypalAccount . "<br />\n";
        echo "logpath: " . $logpath . DIRECTORY_SEPARATOR . $paypallogfile . "<br />\n";
        echo "<pre>\n";
        echo "test:\n\n";
        var_dump($this->test);
        if ($this->test == "verify") {
            $model->handleResponse('VERIFIED', true);
        }
        $minpay = $model->getParam('minbuy');
        $maxpay = $model->getParam('maxbuy');
        echo "minpay:\n\n";
        var_dump($minpay);
        echo "maxpay:\n\n";
        var_dump($maxpay);
        echo "getvals:\n\n";
        var_dump($getvals);
        echo "</pre>\n";
        exit;
    }

    private function handleInvalidResponse($model, $failure2file, $notifyError)
    {
        $report = [
            'response_notify-validate' => 'INVALID',
            'post' => $model->postvals
        ];
        if ($failure2file) {
            $model->debugzeile($report, "ERROR: _notify-validate was \"INVALID\"!");
        }
        if ($notifyError == 1) {
            $msg = "ERROR: _notify-validate was \"INVALID\"!!\n\n" . var_export($report, true);
            $model->sendnotify(1, 3, $msg);
        }
    }

    private function handleUnknownResponse($model, $failure2file, $notifyError)
    {
        $report = [
            'response_notify-validate' => $res,
            'post' => $model->postvals
        ];
        if ($failure2file) {
            $model->debugzeile($report, "ERROR: _notify-validate was not \"VERIFIED\" and not \"INVALID\"!");
        }
        if ($notifyError == 1) {
            $msg = "ERROR: _notify-validate was not \"VERIFIED\" and not \"INVALID\"!!\n\n" . var_export($report, true);
            $model->sendnotify(1, 3, $msg);
        }
    }

    private function checkRegionRentExpiration($model)
    {
        // Get region rent expirations
        $expiringRents = $model->getExpiringRegionRents();

        if (!empty($expiringRents)) {
            foreach ($expiringRents as $rent) {
                $msg = "Region Rent Expiration Alert: Region '{$rent->region_name}' will expire on {$rent->expiration_date}.";
                $model->sendnotify(2, 2, $msg); // Assuming 2 is for rent notifications and 2 is for warning level
            }
        }
    }
}
