<?php
/**
 * @component ZoneNationsPay
 * @copyright Copyright (C) 2023 Druskus ZoneNations https://www.zonenations.com
 * @license GNU/GPL v2 http://www.gnu.org/licenses/gpl-2.0.html
 */

defined('_JEXEC') or die('Restricted access');

use Joomla\CMS\Language\Text;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Uri\Uri;

HTMLHelper::_('behavior.core');
HTMLHelper::_('script', 'com_zonenationspay/paypal.js', ['version' => 'auto', 'relative' => true]);
HTMLHelper::_('stylesheet', 'com_zonenationspay/zonenationspay.css', ['version' => 'auto', 'relative' => true]);

$inWorldCurrencyName = $this->params->get('inworld_currency_name', 'IWC');
?>

<div class="zonenationspay-paypal<?php echo $this->pageclass_sfx; ?>">
    <h1><?php echo Text::_('COM_ZONENATIONSPAY_BUY_IWC'); ?></h1>

    <?php echo $this->pretext; ?>

    <form action="<?php echo $this->cparams['paypal_action']; ?>" method="post" name="paypalForm" id="paypalForm" onsubmit="return checkPayPalForm();">
        <input type="hidden" name="minbuymessage" id="minbuymessage" value="<?php echo Text::sprintf('COM_ZONENATIONSPAY_MINBUYERROR', $this->cparams['currency'], $this->cparams['minbuy']); ?>" />
        <input type="hidden" name="maxbuymessage" id="maxbuymessage" value="<?php echo Text::sprintf('COM_ZONENATIONSPAY_MAXBUYERROR', $this->cparams['currency'], $this->cparams['maxbuy']); ?>" />
        <input type="hidden" name="zonenationspay_xchangerate" id="zonenationspay_xchangerate" value="<?php echo $this->cparams['currencyratebuy']; ?>" />
        <input type="hidden" name="cmd" value="_cart" />
        <input type="hidden" name="custom" value="<?php echo $this->userUUID . ':' . $this->user->id; ?>" />
        <input type="hidden" id="zonenationspay_iwcurrencyname" name="zonenationspay_iwcurrencyname" value="<?php echo $inWorldCurrencyName; ?>" />
        <input type="hidden" id="zonenationspay_item" name="item_name_1" value="<?php echo $inWorldCurrencyName . ' ' . $this->defaultvalueIW; ?>" />
        <input type="hidden" name="upload" value="1" />
        <input type="hidden" name="business" value="<?php echo $this->cparams['paypal_account']; ?>" />
        <input type="hidden" name="currency_code" value="<?php echo $this->cparams['currency']; ?>" />
        <input type="hidden" name="notify_url" value="<?php echo $this->notifyurl; ?>" />
        <input type="hidden" name="return" value="<?php echo $this->successurl; ?>" />
        <input type="hidden" name="cancel_return" value="<?php echo $this->cancelurl; ?>" />
        <input type="hidden" name="hasfee" id="zonenationspay_hasfee" value="<?php echo $this->cparams['hasfee']; ?>" />
        <input type="hidden" name="transactionfee" id="zonenationspay_transactionfee" value="<?php echo $this->cparams['transactionfee']; ?>" />
        <input type="hidden" name="transactionfeetype" id="zonenationspay_transactionfeetype" value="<?php echo $this->cparams['transactionfeetype']; ?>" />
        <input type="hidden" name="minbuy" id="zonenationspay_minbuy" value="<?php echo sprintf("%01.2f", $this->cparams['minbuy']); ?>" />
        <input type="hidden" name="maxbuy" id="zonenationspay_maxbuy" value="<?php echo sprintf("%01.2f", $this->cparams['maxbuy']); ?>" />
        <input type="hidden" name="amount_1" id="zonenationspay_amount_1" value="<?php echo $this->total; ?>" />
        <input type="hidden" name="rm" value="2" />

        <div id="ZoneNationsPay_PayPalTable" class="zonenationspay-paypal-table">
            <div class="row">
                <div class="col-md-6">
                    <?php echo Text::_('COM_ZONENATIONSPAY_BUYFOR') . ' ' . $this->cparams['currency']; ?>
                    <input type="text" name="zonenationspay_amount" id="zonenationspay_rlcurrency" class="form-control" value="<?php echo $this->defaultvalueRL; ?>" onchange="zonenationspayUpdate();" />
                </div>
                <div class="col-md-6">
                    = <?php echo $inWorldCurrencyName; ?> <span id="ZoneNationsPayIW1"><?php echo $this->defaultvalueIW; ?></span>
                </div>
            </div>
            <?php if ($this->cparams['hasfee']) : ?>
                <div class="row">
                    <div class="col-md-6">
                        <?php echo Text::_('COM_ZONENATIONSPAY_TRANSACTIONFEE') . ' ' . $this->cparams['currency']; ?>
                        <span id="ZoneNationsPayTransactionFee"><?php echo $this->transactionfee; ?></span>
                    </div>
                    <div class="col-md-6">&nbsp;</div>
                </div>
                <div class="row">
                    <div class="col-md-6">
                        <?php echo Text::_('COM_ZONENATIONSPAY_PAYTOTAL') . ' ' . $this->cparams['currency']; ?>
                        <span id="ZoneNationsPayRLtotal"><?php echo $this->total; ?></span>
                    </div>
                    <div class="col-md-6">
                        <?php echo Text::_('COM_ZONENATIONSPAY_PAYFOR') . ' ' . $inWorldCurrencyName; ?>
                        <span id="ZoneNationsPayIW2"><?php echo $this->defaultvalueIW; ?></span>
                    </div>
                </div>
            <?php endif; ?>
            <div class="row mt-3">
                <div class="col-md-12 text-center">
                    <button type="submit" class="btn btn-primary">
                        <?php echo Text::_('COM_ZONENATIONSPAY_CHECKOUT'); ?>
                    </button>
                </div>
            </div>
        </div>
    </form>

    <?php echo $this->posttext; ?>

    <?php if ($this->params->get('show_regionrent', 1) && !empty($this->regionrent_info)) : ?>
        <div class="zonenationspay-regionrent mt-4">
            <h3><?php echo Text::_('COM_ZONENATIONSPAY_REGIONRENT_INFO'); ?></h3>
            <table class="table table-striped">
                <thead>
                    <tr>
                        <th><?php echo Text::_('COM_ZONENATIONSPAY_REGIONRENT_NAME'); ?></th>
                        <th><?php echo Text::_('COM_ZONENATIONSPAY_REGIONRENT_DUE_DATE'); ?></th>
                        <th><?php echo Text::_('COM_ZONENATIONSPAY_REGIONRENT_AMOUNT'); ?></th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($this->regionrent_info as $region) : ?>
                        <tr>
                            <td><?php echo $this->escape($region->name); ?></td>
                            <td><?php echo HTMLHelper::_('date', $region->due_date, Text::_('DATE_FORMAT_LC4')); ?></td>
                            <td><?php echo $region->amount . ' ' . $inWorldCurrencyName; ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    <?php endif; ?>
</div>

