<?php
/**
 * @component ZoneNationsPay
 * @copyright Copyright (C) 2023 Druskus ZoneNations https://www.zonenations.com
 * @license GNU/GPL v2 http://www.gnu.org/licenses/gpl-2.0.html
 */

// No direct access
defined('_JEXEC') or die('Restricted access');

use Joomla\CMS\MVC\View\HtmlView;
use Joomla\CMS\Factory;
use Joomla\CMS\Uri\Uri;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Component\ComponentHelper;

class ZonenationspayViewPaypal extends HtmlView
{
    public function display($tpl = null)
    {
        $this->assetpath = Uri::base(true) . "/components/com_zonenationspay/assets/";
        $wa = $this->document->getWebAssetManager();
        $wa->registerAndUseStyle('zonenationspay', 'com_zonenationspay/zonenationspay.css');
        $wa->registerAndUseScript('zonenationspay', 'com_zonenationspay/zonenationspay.js');

        $model = $this->getModel('paypal');
        $cparams = ComponentHelper::getParams('com_zonenationspay');
        $this->itemid = Factory::getApplication()->input->get('Itemid');
        $task = Factory::getApplication()->input->get('task');

        switch ($task) {
            case "cancel":
                $this->canceltext = $cparams->get('cancel_message');
                $tpl = "cancel";
                break;
            case "success":
                $this->successtext = $cparams->get('success_message');
                $tpl = "success";
                break;
            default:
                $this->inworldlink = "index.php?option=com_zonenations&view=inworld&Itemid=" . $this->itemid;
                $this->createlink = Text::sprintf('COM_ZONENATIONSPAY_ERROR_NEEDRELATION_Q1', $this->inworldlink);
                $user = Factory::getUser();
                if ($user->guest) {
                    Factory::getApplication()->enqueueMessage(Text::_('COM_ZONENATIONSPAY_ERROR_LOGINFIRST'), 'warning');
                    $tpl = "needlogin";
                } else {
                    $opensimUID = $model->getUUID($user->id);
                    if (!$opensimUID) {
                        Factory::getApplication()->enqueueMessage(Text::_('COM_ZONENATIONSPAY_ERROR_NEEDRELATION'), 'warning');
                        $tpl = "needrelation";
                    } else {
                        $user->UUID = $opensimUID;
                        $model->checkUserLimits();
                    }
                }
                $this->user = $user;
                $this->userUUID = $user->UUID;
                $transactionfee = (int)$cparams->get('transactionfee');
                $this->cparams = $cparams;
                $this->pretext = $cparams->get('pre_message');
                $this->posttext = $cparams->get('post_message');
                $defaultvalue = $model->getDefaultValue();
                $this->defaultvalueRL = $defaultvalue;
                $iwcurrency = $defaultvalue * $cparams->get('currencyratebuy');
                $this->defaultvalueIW = $iwcurrency;
                if ($cparams->get('hasfee')) {
                    if ($cparams->get('transactionfeetype') == "percent") {
                        $transactionfee = $defaultvalue / 100 * $cparams->get('transactionfee');
                        $total = $defaultvalue + $transactionfee;
                    } else {
                        $transactionfee = $cparams->get('transactionfee');
                        $total = $defaultvalue + $transactionfee;
                    }
                } else {
                    $total = $defaultvalue;
                }
                $this->total = round($total, 2);
                $this->transactionfee = $transactionfee;
                if ((int)$cparams->get('userlimit_day') > 0 && $user->limitDay >= $cparams->get('userlimit_day')) {
                    $tpl = "limit_day";
                } elseif ((int)$cparams->get('userlimit_week') > 0 && $user->limitWeek >= $cparams->get('userlimit_week')) {
                    $tpl = "limit_week";
                } elseif ((int)$cparams->get('userlimit_month') > 0 && $user->limitMonth >= $cparams->get('userlimit_month')) {
                    $tpl = "limit_month";
                }
                $this->notifyurl = Uri::base() . "index.php?option=com_zonenationspay&view=notify&tmpl=component";
                $this->successurl = Uri::base() . "index.php?option=com_zonenationspay&view=paypal&task=success&Itemid=" . $this->itemid;
                $this->cancelurl = Uri::base() . "index.php?option=com_zonenationspay&view=paypal&task=cancel&Itemid=" . $this->itemid;

                // Add regionrent information
                $this->regionrent_info = $model->getRegionRentInfo($user->id);
                break;
        }

        parent::display($tpl);
    }
}
