<?php
/**
 * @component ZoneNationsPay
 * @copyright Copyright (C) 2023 Druskus ZoneNations https://www.zonenations.com
 * @license GNU/GPL v2 http://www.gnu.org/licenses/gpl-2.0.html
 */

defined('_JEXEC') or die('Restricted access');

use Joomla\CMS\Language\Text;
use Joomla\CMS\HTML\HTMLHelper;

HTMLHelper::_('behavior.core');
HTMLHelper::_('stylesheet', 'com_zonenationspay/zonenationspay.css', ['version' => 'auto', 'relative' => true]);
?>

<div class="zonenationspay-transactionlist<?php echo $this->pageclass_sfx; ?>">
    <h1><?php echo Text::_('COM_ZONENATIONSPAY_TRANSACTIONLIST'); ?></h1>

    <!-- PayPal Transactions Table -->
    <h2><?php echo Text::_('COM_ZONENATIONSPAY_TRANSACTIONLIST_PAYPAL'); ?></h2>
    <table class="table table-striped table-hover">
        <thead>
            <tr>
                <th><?php echo $this->currencyname; ?></th>
                <th><?php echo $this->params->get('inworld_currency_name', 'IWC'); ?></th>
                <th><?php echo Text::_('COM_ZONENATIONSPAY_TRANSACTIONLIST_DATE'); ?></th>
                <th><?php echo Text::_('COM_ZONENATIONSPAY_TRANSACTIONLIST_ACCOUNT'); ?></th>
            </tr>
        </thead>
        <tbody>
            <?php if (!empty($this->paypalList)) : ?>
                <?php foreach ($this->paypalList as $paypaltransaction) : ?>
                    <tr>
                        <td><?php echo HTMLHelper::_('number.format', $paypaltransaction->amount_rlc, 2); ?></td>
                        <td><?php echo HTMLHelper::_('number.format', $paypaltransaction->amount_iwc, 0); ?></td>
                        <td><?php echo HTMLHelper::_('date', $paypaltransaction->transactiontime, Text::_('DATE_FORMAT_LC5')); ?></td>
                        <td><?php echo $this->escape($paypaltransaction->payer_email); ?></td>
                    </tr>
                <?php endforeach; ?>
            <?php else : ?>
                <tr>
                    <td colspan="4"><?php echo Text::_('COM_ZONENATIONSPAY_TRANSACTIONLIST_PAYPAL_EMPTY'); ?></td>
                </tr>
            <?php endif; ?>
        </tbody>
    </table>

    <?php if ($this->params->get('show_regionrent', 1)) : ?>
        <!-- Region Rent Transactions Table -->
        <h2 class="mt-4"><?php echo Text::_('COM_ZONENATIONSPAY_REGIONRENT_TRANSACTIONS'); ?></h2>
        <table class="table table-striped table-hover">
            <thead>
                <tr>
                    <th><?php echo Text::_('COM_ZONENATIONSPAY_REGIONRENT_NAME'); ?></th>
                    <th><?php echo $this->params->get('inworld_currency_name', 'IWC'); ?></th>
                    <th><?php echo Text::_('COM_ZONENATIONSPAY_REGIONRENT_DUE_DATE'); ?></th>
                    <th><?php echo Text::_('COM_ZONENATIONSPAY_REGIONRENT_STATUS'); ?></th>
                </tr>
            </thead>
            <tbody>
                <?php if (!empty($this->regionrentList)) : ?>
                    <?php foreach ($this->regionrentList as $regionrent) : ?>
                        <tr>
                            <td><?php echo $this->escape($regionrent->region_name); ?></td>
                            <td><?php echo HTMLHelper::_('number.format', $regionrent->amount, 0); ?></td>
                            <td><?php echo HTMLHelper::_('date', $regionrent->due_date, Text::_('DATE_FORMAT_LC5')); ?></td>
                            <td><?php echo $this->escape($regionrent->status); ?></td>
                        </tr>
                    <?php endforeach; ?>
                <?php else : ?>
                    <tr>
                        <td colspan="4"><?php echo Text::_('COM_ZONENATIONSPAY_REGIONRENT_TRANSACTIONS_EMPTY'); ?></td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>
    <?php endif; ?>
</div>


