<?php
/**
 * @component ZoneNationsPay
 * @copyright Copyright (C) 2023 Druskus ZoneNations https://www.zonenations.com
 * @license GNU/GPL v2 http://www.gnu.org/licenses/gpl-2.0.html
 */

defined('_JEXEC') or die('Restricted access');

use Joomla\CMS\MVC\View\HtmlView;
use Joomla\CMS\Factory;
use Joomla\CMS\Uri\Uri;
use Joomla\CMS\Language\Text;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Component\ComponentHelper;

class ZonenationspayViewTransactionlist extends HtmlView
{
    protected $paypalList;
    protected $payoutList;
    protected $regionrentList;
    protected $user;
    protected $userUUID;
    protected $currencyname;
    protected $itemid;
    protected $revokeimage;
    protected $params;
    protected $showRegionRent;

    public function display($tpl = null)
    {
        $this->params = ComponentHelper::getParams('com_zonenationspay');
        $app = Factory::getApplication();
        $wa = $app->getDocument()->getWebAssetManager();

        $wa->registerAndUseStyle('zonenationspay', 'com_zonenationspay/zonenationspay.css');
        $wa->registerAndUseScript('zonenationspay', 'com_zonenationspay/zonenationspay.js');

        $model = $this->getModel('transactionlist');
        $this->currencyname = $this->params->get('currency', 'USD');
        $this->itemid = $app->input->getInt('Itemid');

        $user = Factory::getUser();
        if ($user->guest) {
            $app->enqueueMessage(Text::_('COM_ZONENATIONSPAY_ERROR_LOGINFIRST'), 'warning');
            $tpl = "needlogin";
        } else {
            $opensimUID = $model->getUUID($user->id);
            $user->UUID = $opensimUID;

            if ($this->params->get('show_paypal_transactions', 1)) {
                $this->paypalList = $model->paypalList($user->id);
            }

            if ($this->params->get('show_payout_transactions', 1)) {
                $this->payoutList = $model->payoutList($user->id);
                $this->payoutList = $model->addPayOutImage($this->payoutList);
            }

            // Region Rent specific code
            $this->showRegionRent = $this->params->get('show_regionrent_transactions', 1);
            if ($this->showRegionRent) {
                $this->regionrentList = $model->regionrentList($user->id);
                
                // Check if there are any upcoming rent payments
                $upcomingRents = $model->getUpcomingRegionRents($user->id);
                if (!empty($upcomingRents)) {
                    $app->enqueueMessage(Text::_('COM_ZONENATIONSPAY_UPCOMING_RENT_PAYMENTS'), 'notice');
                }

                // Get total rent due
                $totalRentDue = $model->getTotalRentDue($user->id);
                $this->totalRentDue = $totalRentDue;

                // Add region rent summary
                $this->regionRentSummary = $model->getRegionRentSummary($user->id);
            }
        }

        $this->revokeimage = HTMLHelper::_('image', 'com_zonenationspay/trash.png', Text::_('COM_ZONENATIONSPAY_PAYOUT_REVOKE'), ['title' => Text::_('COM_ZONENATIONSPAY_PAYOUT_REVOKE')], true);

        $this->user = $user;
        $this->userUUID = $user->UUID;

        parent::display($tpl);
    }
}
