<?php
/**
 * @component ZoneNationsPay
 * @copyright Copyright (C) 2023 Druskus ZoneNations https://www.zonenations.com
 * @license GNU/GPL v2 http://www.gnu.org/licenses/gpl-2.0.html
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

// No direct access
defined('_JEXEC') or die('Restricted access');

use Joomla\CMS\Factory;
use Joomla\CMS\MVC\Controller\BaseController;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Component\ComponentHelper;

// Require the base controller
require_once(JPATH_COMPONENT . '/controller.php');

// Get an instance of the controller
$controller = BaseController::getInstance('ZoneNationsPay');

// Get the task
$input = Factory::getApplication()->input;
$task = $input->getCmd('task', '');

// Initialize component parameters
$params = ComponentHelper::getParams('com_zonenationspay');

// Check if we need to initialize the money settings
if (!defined('COM_ZONENATIONSPAY_INWORLD_CURRENCYNAME')) {
    $model = $controller->getModel('zonenationspay');
    $money = $model->getMoneySettings();
    $sandboxmode = $params->get('sandboxmode', 0);
    $noadd = $input->getInt('noadd', 0);

    if ($sandboxmode && $noadd == 0) {
        Factory::getApplication()->enqueueMessage(Text::_('COM_ZONENATIONSPAY_SANDBOXMODE'), 'warning');
    }

    if (!empty($money['name'])) {
        define('COM_ZONENATIONSPAY_INWORLD_CURRENCYNAME', $money['name']);
    }
}

// Handle BTCPay IPN separately
if ($task == 'btcpayIPN') {
    $controller->execute($task);
} else {
    // Perform the requested task
    $controller->execute($task);

    // Additional code for region rent
    if ($input->getCmd('view') === 'regionrent') {
        // Load the region rent model
        $model = $controller->getModel('regionrent');

        // Check for upcoming rent payments
        $upcomingRents = $model->getUpcomingRentPayments();
        if (!empty($upcomingRents)) {
            Factory::getApplication()->enqueueMessage(Text::_('COM_ZONENATIONSPAY_UPCOMING_RENT_PAYMENTS'), 'notice');
        }

        // Check for overdue rent payments
        $overdueRents = $model->getOverdueRentPayments();
        if (!empty($overdueRents)) {
            Factory::getApplication()->enqueueMessage(Text::_('COM_ZONENATIONSPAY_OVERDUE_RENT_PAYMENTS'), 'warning');
        }
    }
}

// Redirect if set by the controller
$controller->redirect();
